# Table of Contents

- [updating-lifecycle-phases](<./updating-lifecycle-phases.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Updating Lifecycle Phases](<./Updating-Lifecycle-Phases.md>)
  - [Overview](<./Updating-Lifecycle-Phases/Overview.md>)
  - [Configuration](<./Updating-Lifecycle-Phases/Configuration.md>)
  - [Script](<./Updating-Lifecycle-Phases/Script.md>)
